@@ -58,7 +58,8 @@ def readBmp(files,imgw=None,imgh=None,imgf=None):
         img = img / 255.
         #img = img * 255.0
         #print(img.astype(int)[0][0][0])
-        
+        if len(list(img.shape)) == 2:
+            img = np.reshape(img,(imgw,imgh,1))
         #print(img)
         
         #img = tf.image.resize(img,[imgw,imgh])
