@@ -95,6 +95,8 @@ class TrainProxy:
         
         class_count = len(config["LabelList"])
         
+        prestop = int(superparam["PreStop"])
+        
         net = getNeuralNet(net_name)
         net.initModel(class_count)
         
@@ -104,7 +106,7 @@ class TrainProxy:
         os.makedirs(os.path.dirname(train_ckpt),exist_ok=True)
         os.makedirs(os.path.dirname(valid_ckpt),exist_ok=True)
         
-        model_ft = net.loadModel(train_ckpt)
+        model_ft = net.loadModel(valid_ckpt)
         
         loaders = getLoaders(projectid,modelid,net)
         
@@ -120,6 +122,8 @@ class TrainProxy:
         max_train_acc = 0.0
         max_valid_acc = 0.0
         
+        save_epoch = 0
+        
         trainlog = PathProxy.getTrainProcessValues(projectid,modelid)
         #train process
         for i in range(epchos):
@@ -159,12 +163,21 @@ class TrainProxy:
                 net.saveModel(valid_ckpt)
                 max_valid_acc = epoch_acc
                 saveModelEpoch(valid_ckpt)
+                
+                save_epoch = i
+            
+            
+            
             print("[validing] at epcho:{}/{},loss = {}, acc = {}".format(i,epchos,epoch_loss,epoch_acc))
             
             valid_epoch_loss = epoch_loss
             valid_epoch_acc = epoch_acc
             tlog.add(trainlog,(train_epoch_loss,train_epoch_acc,0.0,valid_epoch_loss,valid_epoch_acc,0.0))
             
+            if i - save_epoch > prestop:
+                print("prestop because acc is not raise in the last 10 epoch")
+                break
+            
         pass
 
 def test():
